Reducers
--------

Reduction functions from the awkward-array API. Dedicated Dask
specific API documentation will be added here; for now please consult
the awkward-array API docs.

.. currentmodule:: dask_awkward

..
   .. autosummary::

      all
      any
      argmax
      argmin
      corr
      count
      count_nonzero
      covar
      linear_fit
      max
      mean
      min
      moment
      prod
      ptp
      softmax
      std
      sum
      var

   .. autofunction:: all
   .. autofunction:: any
   .. autofunction:: argmax
   .. autofunction:: argmin
   .. autofunction:: corr
   .. autofunction:: count
   .. autofunction:: count_nonzero
   .. autofunction:: covar
   .. autofunction:: linear_fit
   .. autofunction:: max
   .. autofunction:: mean
   .. autofunction:: min
   .. autofunction:: moment
   .. autofunction:: prod
   .. autofunction:: ptp
   .. autofunction:: softmax
   .. autofunction:: std
   .. autofunction:: sum
   .. autofunction:: var
